@@ -28,9 +28,15 @@ json={"username":username,'password':password})
         'authorization':'Bearer '+self.access_token
     })
         print(f"heat output {x.text}")
-        return json.loads(x.text)    
+        data = json.loads(x.text)
+        unit = customer_info['preferences']['temperature_unit']
+        data['summary']['avg']=data['summary']['avg_celsius']
+        if unit=='fahrenheit':
+            data['summary']['avg']=data['summary']['avg_fahrenheit']
+        data['summary']['unit']=unit    
+        return data,200    
 
-    def get_current_water(hub_id,username,password):
+    def get_current_water(self,username,password):
         self.login(username,password)
         customer_info = self.get_customer_info()
         print(f"got customer info")
@@ -41,7 +47,14 @@ json={"username":username,'password':password})
     headers={
         'authorization':'Bearer '+self.access_token
     })
-        return json.loads(x.text)    
+        data = json.loads(x.text)
+        unit = customer_info['preferences']['tank_capacity_unit']
+        data['summary']['avg']=data['summary']['total_water_liters']
+        if unit=='gallons':
+            data['summary']['avg']=data['summary']['total_water_gallons']
+
+        data['summary']['unit']=unit
+        return data,200    
 
     def get_customer_info(self):
         x = requests.get(f'{config.BASE_USER_API_URL}/customer',
@@ -51,4 +64,5 @@ json={"username":username,'password':password})
         return json.loads(x.text)    
    
 if __name__ == "__main__":
-    api = UserAPI()
\ No newline at end of file
+    api = UserAPI()
+    api.get_current_water('manuel@powerx.co','test123')
\ No newline at end of file
